NudgeKeyUtility class

Constructors

NudgeKeyUtility()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

offset double
getter/setter pair
scrollController ScrollController
getter/setter pair
widgetDetailsList List<Map<String, dynamic>>
getter/setter pair

Static Methods

generateKeysAndUpdateDetails(int numberOfKeys, BuildContext context) List<GlobalKey<State<StatefulWidget>>>
scrollToWidget({required GlobalKey<State<StatefulWidget>> containerKey, required BuildContext context}) → void
updateNewWidgetDetails(GlobalKey<State<StatefulWidget>> key, int index, BuildContext context) → void
updateWidgetDetails(GlobalKey<State<StatefulWidget>> key, int index, BuildContext context) → void