NudgeKeyUtility class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- offset ↔ double
-
getter/setter pair
- scrollController ↔ ScrollController
-
getter/setter pair
-
widgetDetailsList
↔ List<
Map< String, dynamic> > -
getter/setter pair
Static Methods
-
generateKeysAndUpdateDetails(
int numberOfKeys, BuildContext context) → List< GlobalKey< State< >StatefulWidget> > -
scrollToWidget(
{required GlobalKey< State< containerKey, required BuildContext context}) → voidStatefulWidget> > -
updateNewWidgetDetails(
GlobalKey< State< key, int index, BuildContext context) → voidStatefulWidget> > -
updateWidgetDetails(
GlobalKey< State< key, int index, BuildContext context) → voidStatefulWidget> >